@@ -1,6 +1,7 @@
+from __future__ import annotations
+
 import os
 from argparse import Namespace
-from typing import List
 
 from pvenv.subcommands.base import BaseCommand
 
@@ -8,19 +9,19 @@ from pvenv.subcommands.base import BaseCommand
 class Command(BaseCommand):
     def __init__(self, options: Namespace):
         super().__init__(options)
-        self.env_vars: List[str] = options.env_vars
+        self.env_vars: list[str] = options.env_vars
         self.files = options.files
 
     @staticmethod
-    def parse_env_var(line: str) -> List[str]:
+    def parse_env_var(line: str) -> list[str]:
         return line.split("=", maxsplit=1)
 
     def run(self):
         new_vars = {}
         for file in self.files:
-            with open(file) as f:
-                for line in f:
-                    line = line.strip()
+            with file.open() as f:
+                for raw_line in f:
+                    line = raw_line.strip()
                     if line and not line.startswith("#"):
                         key, value = self.parse_env_var(line)
                         new_vars[key] = value
@@ -31,10 +32,10 @@ class Command(BaseCommand):
         if new_vars:
             if self._prefix in os.environ:
                 raise RuntimeError("Already in a venv, aborting...")
-            print(f"export {self._prefix}=true")
+            self.print(f"export {self._prefix}=true")
         for key, value in new_vars.items():
             if key in os.environ:
-                print(f"export {self._prefix}_{key}={os.getenv(key, '')}")
+                self.print(f"export {self._prefix}_{key}={os.getenv(key, '')}")
             else:
-                print(f"export {self._prefix}_unset_{key}=")
-            print(f"export {key}={value}")
+                self.print(f"export {self._prefix}_unset_{key}=")
+            self.print(f"export {key}={value}")
