@@ -1,10 +1,13 @@
 from argparse import Namespace
 from pathlib import Path
 
+from pvenv.subcommands.base import BaseCommand
 
-class Command:
-    def __init__(self, base_dir: Path, _options: Namespace):
-        self.base_dir = base_dir
+
+class Command(BaseCommand):
+    def __init__(self, options: Namespace):
+        super().__init__(options)
+        self.base_dir: Path = options.base_dir
 
     def run(self):
         for directory in sorted(self.base_dir.glob("*")):
