@@ -1,7 +1,8 @@
+from __future__ import annotations
+
 import shutil
 from argparse import Namespace
 from pathlib import Path
-from typing import List
 
 from pvenv.subcommands.base import BaseCommand
 
@@ -10,7 +11,7 @@ class Command(BaseCommand):
     def __init__(self, options: Namespace):
         super().__init__(options)
         self.base_dir: Path = options.base_dir
-        self.venv_to_remove: List[str] = options.venvs_to_remove
+        self.venv_to_remove: list[str] = options.venvs_to_remove
 
     def run(self):
         for venv in self.venv_to_remove:
